HasDensePolynomialConfig

Trait HasDensePolynomialConfig 

pub trait HasDensePolynomialConfig: SemiringConfig + Sized {
    // Provided method
    fn dense_poly_cfg<const DEGREE_PLUS_ONE: usize>(
        &self,
    ) -> DensePolynomialConfig<'_, Self, DEGREE_PLUS_ONE> { ... }
}
Extension trait providing DensePolynomialConfig from a coefficient config, so that the same config can be used to perform operations on dynamic polynomials: cfg.poly_cfg().mul(&p, &q).

Provided Methods

fn dense_poly_cfg<const DEGREE_PLUS_ONE: usize>( &self, ) -> DensePolynomialConfig<'_, Self, DEGREE_PLUS_ONE>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<S: SemiringConfig> HasDensePolynomialConfig for S